import numpy as np
from scipy.stats import logistic


def sample_trunc_logistic(a, b, loc, scale):
  u = np.random.uniform()
  return logistic.ppf(
      u * (logistic.cdf(b, loc=loc, scale=scale) - logistic.cdf(a, loc=loc, scale=scale)) +
      logistic.cdf(a, loc=loc, scale=scale),
      loc=loc, scale=scale
      )

def get_sur_resid(model, results):
  y = results.endog
  response_values = np.sort(np.unique(y))
  classes = len(response_values)
  mean_response_value = results.predict(which="linpred") - results.params.iloc[1-classes]
  cut_points = model.transform_threshold_params(results.params[1-classes:])
  cut_points = cut_points - cut_points[1]
  s = [sample_trunc_logistic(cut_points[y[i]], cut_points[y[i]+1], mean_response_value[i], 1) for i in range(len(y))] # Currently assuming that y takes sequential integer values starting at 0
  return s - mean_response_value


import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="pysure",
    version="0.1.1",
    description="Surrogate residuals for logistic regression",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/jmccrosky/pysure",
    author="Jesse McCrosky",
    author_email="mccrosky@gmail.com",
    license="MIT",
    packages=["pysure"],
    package_dir={'': 'src'},
    include_package_data=True,
)
